@@ -62,6 +62,15 @@ var commentOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::a: cat\n# cat\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "Set foot comment, using an expression",
+		document:    "a: cat\n\n# hi",
+		expression:  `. foot_comment=""`,
+		expected: []string{
+			"D0, P[], (doc)::a: cat\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `a: cat`,
@@ -112,6 +121,24 @@ var commentOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!str)::welcome!\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "strip trailing comment recurse all",
+		document:    "a: cat\n\n# haha",
+		expression:  `... comments= ""`,
+		expected: []string{
+			"D0, P[], (!!map)::a: cat\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "strip trailing comment recurse values",
+		document:    "a: cat\n\n# haha",
+		expression:  `.. comments= ""`,
+		expected: []string{
+			"D0, P[], (!!map)::a: cat\n",
+		},
+	},
 	{
 		description:           "Head comment with document split",
 		dontFormatInputForDoc: true,
